@@ -151,12 +151,12 @@ CAutostart::CAutostart(TQWidget *parent, const char *name, const TQStringList&)
   btnRemove->setText( i18n( "&Remove" ) );
   btnProperties->setText( i18n( "&Properties" ) );
 
-  connect( btnAdd, TQT_SIGNAL(clicked()), TQT_SLOT(addCMD()) );
-  connect( btnRemove, TQT_SIGNAL(clicked()), TQT_SLOT(removeCMD()) );
-  connect( listCMD, TQT_SIGNAL(doubleClicked(TQListViewItem*)), TQT_SLOT(editCMD() ));
-  connect( btnProperties, TQT_SIGNAL(clicked()), TQT_SLOT(editCMD()) );
-  connect( cmbStartOn, TQT_SIGNAL(activated(int)), TQT_SLOT(setStartOn(int)) );
-  connect( listCMD, TQT_SIGNAL(selectionChanged(TQListViewItem*)), TQT_SLOT(selectionChanged(TQListViewItem*)) );
+  connect( btnAdd, TQ_SIGNAL(clicked()), TQ_SLOT(addCMD()) );
+  connect( btnRemove, TQ_SIGNAL(clicked()), TQ_SLOT(removeCMD()) );
+  connect( listCMD, TQ_SIGNAL(doubleClicked(TQListViewItem*)), TQ_SLOT(editCMD() ));
+  connect( btnProperties, TQ_SIGNAL(clicked()), TQ_SLOT(editCMD()) );
+  connect( cmbStartOn, TQ_SIGNAL(activated(int)), TQ_SLOT(setStartOn(int)) );
+  connect( listCMD, TQ_SIGNAL(selectionChanged(TQListViewItem*)), TQ_SLOT(selectionChanged(TQListViewItem*)) );
 
   listCMD->setFocus();
 
